@@ -1,6 +1,7 @@
 from typing import Any, Dict, Optional, Type, TypeVar
 
 import httpx
+import pydantic
 
 from myst.auth.credentials import Credentials
 from myst.models.base_model import BaseModel
@@ -99,7 +100,10 @@ class Client:
             return response_class.parse_raw(response.content)
         elif response.status_code == 422:
             # Special-case 422 validation errors.
-            raise MystClientError(HTTPValidationError.parse_raw(response.content))
+            try:
+                raise MystClientError(HTTPValidationError.parse_raw(response.content))
+            except pydantic.ValidationError:
+                raise MystClientError(StringDetailError.parse_raw(response.content))
         elif response.status_code == 404:
             raise NotFound(message=StringDetailError.parse_raw(response.content).detail)
         elif 400 <= response.status_code < 500:
