@@ -1,4 +1,5 @@
+from myst.connectors.operation_connectors.get_dummies import GetDummies
 from myst.connectors.operation_connectors.numerical_expression import NumericalExpression
 from myst.connectors.operation_connectors.time_transformations import TimeTransformations
 
-__all__ = ["NumericalExpression", "TimeTransformations"]
+__all__ = ["NumericalExpression", "TimeTransformations", "GetDummies"]
