@@ -1,7 +1,6 @@
 from myst.client import Client
-
-from ...models.user_get import UserGet
-from ...models.user_update import UserUpdate
+from myst.openapi.models.user_get import UserGet
+from myst.openapi.models.user_update import UserUpdate
 
 
 def request_sync(client: Client, uuid: str, json_body: UserUpdate) -> UserGet:
