@@ -1,3 +1,5 @@
+from typing import Optional
+
 from pydantic import Field
 from typing_extensions import Literal
 
@@ -7,5 +9,5 @@ from myst.models import base_model
 class DeploymentCreate(base_model.BaseModel):
     """Schema for deployment create requests."""
 
-    object_: Literal["Deployment"] = Field(..., alias="object")
     title: str
+    object_: Optional[Literal["Deployment"]] = Field("Deployment", alias="object")
