@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.deployment_get import DeploymentGet
+from myst.openapi.models.deployment_get import DeploymentGet
 
 
 class DeploymentList(base_model.BaseModel):
