@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.layer_get import LayerGet
+from myst.openapi.models.layer_get import LayerGet
 
 
 class LayerList(base_model.BaseModel):
