@@ -4,8 +4,7 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.job_state import JobState
+from myst.openapi.models.job_state import JobState
 
 
 class NodeRunJobGet(base_model.BaseModel):
@@ -22,3 +21,5 @@ class NodeRunJobGet(base_model.BaseModel):
     state: JobState
     update_time: Optional[str] = None
     result: Optional[str] = None
+    error_reason: Optional[str] = None
+    error_edge: Optional[str] = None
