@@ -71,6 +71,7 @@ def example_model(example_project: Dict[str, Any]) -> Dict[str, Any]:
         creator="fb80ae8a-dc73-45f3-9a49-ca57202b8fdf",
         deploy_status="NEW",
         connector_uuid="b78ff94a-27b1-4986-a88a-536661239bb2",
+        input_specs_schema=dict(foo="bar"),
         parameters=dict(
             num_boost_round=10,
             max_depth=6,
@@ -103,6 +104,7 @@ def example_operation(example_project: Dict[str, Any]) -> Dict[str, Any]:
         creator="fb80ae8a-dc73-45f3-9a49-ca57202b8fdf",
         deploy_status="NEW",
         connector_uuid="e4bebd6d-d9d2-4103-8c94-95fa162eddc0",
+        input_specs_schema=dict(foo="bar"),
         parameters=dict(
             rolling_window_parameters=dict(
                 window_period="PT3H", min_periods=1, centered=False, aggregation_function="mean"
@@ -225,4 +227,5 @@ def example_result() -> Dict[str, Any]:
         start_time="2021-03-17T00:00:10Z",
         end_time="2021-03-17T00:03:42Z",
         result_url="https://storage.cloud.google.com/backtest-result/37faf8b5-5a4e-40e5-b90a-439a9743f921.json",
+        metrics=dict(mape=1.4, mae=43, rmse=1.39348),
     )
