@@ -4,7 +4,7 @@ from myst.adapters.timing import to_timing_create
 from myst.client import get_client
 from myst.models.timing import AbsoluteOrRelativeTiming, TimeRangeBoundary, from_time_range_boundary
 from myst.models.types import ItemOrSlice
-from myst.openapi.api.time_series import create_time_series_layer
+from myst.openapi.api.projects.time_series.layers import create_time_series_layer
 from myst.openapi.models.layer_create import LayerCreate
 from myst.resources.edge import Edge
 from myst.resources.node import Node
@@ -46,6 +46,7 @@ class Layer(Edge):
     ) -> "Layer":
         layer = create_time_series_layer.request_sync(
             client=get_client(),
+            project_uuid=str(downstream_node.project),
             time_series_uuid=str(downstream_node.uuid),
             json_body=LayerCreate(
                 object="Edge",
