@@ -1,11 +1,12 @@
 import json
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional
 from uuid import UUID
 
 import httpx
 
 from myst.client import get_client
 from myst.core.time.time import Time
+from myst.models.time_dataset import TimeDataset
 from myst.openapi.api.projects.models.fit_results import get_model_fit_result
 from myst.resources.resource import Resource
 
@@ -52,3 +53,22 @@ class ModelFitResult(NodeResult):
             return json.loads(response.content)
         else:
             raise RuntimeError("Could not download fit state.")
+
+
+class ModelRunResultMetadata(NodeResult):
+    """Describes the metadata of a result produced by a model run.
+
+    This representation does not contain the inputs and outputs of a model run.
+    """
+
+
+class ModelRunResult(ModelRunResultMetadata):
+    """Describes a result produced by a model run.
+
+    Attributes:
+        inputs: inputs to the model run
+        outputs: outputs of the model run
+    """
+
+    inputs: Dict[str, List[TimeDataset]]
+    outputs: List[TimeDataset]
